@@ -63,7 +63,7 @@ class TestSignAndVerify(unittest.TestCase):
         self.key = read_test_data("test.private")
         self.rfckey = read_test_data("rfc8032_7_1.key")
 
-    def dnsfunc(self, domain):
+    def dnsfunc(self, domain, timeout=5):
         sample_dns = """\
 k=rsa; s=email;\
 p=MFwwDQYJKoZIhvcNAQEBBQADSwAwSAJBANmBe10IgY+u7h3enWTukkqtUD5PR52T\
@@ -87,7 +87,7 @@ Y+vtSBczUiKERHv1yRbcaQtZFh5wtiRrN04BLUTD21MycBX5jYchHjPY/wIDAQAB"""
         self.assertTrue(domain in _dns_responses,domain)
         return _dns_responses[domain]
 
-    def dnsfunc2(self, domain):
+    def dnsfunc2(self, domain, timeout=5):
         sample_dns = """\
 k=rsa; \
 p=MFwwDQYJKoZIhvcNAQEBBQADSwAwSAJBANmBe10IgY+u7h3enWTukkqtUD5PR52T\
@@ -111,7 +111,7 @@ Y+vtSBczUiKERHv1yRbcaQtZFh5wtiRrN04BLUTD21MycBX5jYchHjPY/wIDAQAB"""
         self.assertTrue(domain in _dns_responses,domain)
         return _dns_responses[domain]
 
-    def dnsfunc3(self, domain):
+    def dnsfunc3(self, domain, timeout=5):
         sample_dns = """\
 k=rsa; \
 p=MFwwDQYJKoZIhvcNAQEBBQADSwAwSAJBANmBe10IgY+u7h3enWTukkqtUD5PR52T\
@@ -135,7 +135,7 @@ Y+vtSBczUiKERHv1yRbcaQtZFh5wtiRrN04BLUTD21MycBX5jYchHjPY/wIDAQAB"""
         self.assertTrue(domain in _dns_responses,domain)
         return _dns_responses[domain]
 
-    def dnsfunc4(self, domain):
+    def dnsfunc4(self, domain, timeout=5):
         sample_dns = """\
 k=rsa; \
 p=MFwwDQYJKoZIhvcNAQEBBQADSwAwSAJBANmBe10IgY+u7h3enWTukkqtUD5PR52T\
@@ -159,7 +159,7 @@ Y+vtSBczUiKERHv1yRbcaQtZFh5wtiRrN04BLUTD21MycBX5jYchHjPY/wIDAQAB"""
         self.assertTrue(domain in _dns_responses,domain)
         return _dns_responses[domain]
 
-    def dnsfunc5(self, domain):
+    def dnsfunc5(self, domain, timeout=5):
         sample_dns = """\
 k=rsa; \
 p=MFwwDQYJKoZIhvcNAQEBBQADSwAwSAJBANmBe10IgY+u7h3enWTukkqtUD5PR52T\
@@ -314,6 +314,28 @@ p=11qYAYKxCrfVS/7TyWQHOg7hcvPapiMlrwIaaPcHURo="""
                     sig + self.message + b"foo", dnsfunc=self.dnsfunc)
                 self.assertFalse(res)
 
+    def test_l_verify(self):
+        # Sign with l=, add text, should verify
+        for header_algo in (b"simple", b"relaxed"):
+            for body_algo in (b"simple", b"relaxed"):
+                sig = dkim.sign(
+                    self.message, b"test", b"example.com", self.key,
+                    canonicalize=(header_algo, body_algo), length=True)
+                self.message += b'added more text\n'
+                res = dkim.verify(sig + self.message, dnsfunc=self.dnsfunc)
+                self.assertTrue(res)
+
+    def test_present(self):
+        # Test DKIM.present().
+        d = dkim.DKIM(self.message,signature_algorithm=b'rsa-sha256')
+        present = d.present()
+        self.assertFalse(present)
+        sig = d.sign(b"test", b"example.com", self.key)
+        signed = sig + self.message
+        d2 = dkim.DKIM(signed)
+        present = d2.present()
+        self.assertTrue(present)
+
     def test_badly_encoded_domain_fails(self):
         # Domains should be ASCII. Bad ASCII causes verification to fail.
         sig = dkim.sign(self.message, b"test", b"example.com\xe9", self.key)
